# Xtesting 2020

[Cédric Ollivier](mailto:cedric.ollivier@orange.com)

2020/01/16



## What's new in jerma?


### Increase deployment models

- support multiple deployment models: fully centralized (LFN), distributed or
  mixed of them
- fully support NAT or ssh tunneling model
- support GitlabCI

**selected in CNTT RI and RC!**


### And

- fully manage artifacts publication via S3 (e.g. artificats.opnfv.org)
- dump all log compaign easily via S3 (see Kubernetes Conformance)
- partially integrate a generic dashboard based on Cachet
- add behave driver



## Kali (K-release)


### Ideas

- harden GitlabCI support (check all deployment scenarios)
- improve the testcase runner
- add GNU/Linux packages (then integrate them in GNU/Linux distributions)
- support new drivers?



## Thank You!
